Toolbox Paper Scripts
---------------------

This directory contains scripts to reproduce the results shown in the toolbox paper:

- `ctf_rest` contains scripts for training a TDE-HMM a TDE-DyNeMo model on resting-state MEG data collected using a CTF scanner (Nottingham MRC MEGUK).
- `elekta_task` contains scripts for training an AE-HMM and TDE-HMM on a visual task MEG data collected using an Elekta scanner (Wakeman-Henson).

Both datasets are publicly available.
